==> adlint_1.6.0.orig.tar.gz: adlint-1.6.0/lib/adlint/cpp/asm.rb <==
# Inline assembly notations.
#
# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
# Copyright:: Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
# License::   GPLv3+: GNU General Public License version 3 or later
#
# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>

#--
#     ___    ____  __    ___   _________
#    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
#   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
#  / __  |/ /_/ / /___/ / /|  /  / /
# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
#
# This file is part of AdLint.
#
# AdLint is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# AdLint is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# AdLint.  If not, see <http://www.gnu.org/licenses/>.
#
#++

require "adlint/cpp/subst"

module AdLint #:nodoc:
module Cpp #:nodoc:

  module InlineAssemblyDefinition
    def create_inline_assembly_substitutions(source)
      [create_cxx_asm_definition(source)] +
        create_extended_asm_definitions(source)
    end

    def create_cxx_asm_definition(source)
      CodeSubstitution.new("asm(__adlint__any);", "").tap do |subst|
        subst.on_substitution += lambda { |location, matched|
          source.on_inline_assembly.invoke(location, matched)
        }
      end
    end

    def create_extended_asm_definitions(source)
      [
        "__asm(__adlint__any);",
        "asm { __adlint__any }",
        "__asm { __adlint__any }",
        "__asm__(__adlint__any);",
        "__asm__ volatile (__adlint__any);",
        "__asm__ __volatile__ (__adlint__any);",
        "asm(__adlint__any);",
        "asm volatile (__adlint__any);",
        "asm __volatile__ (__adlint__any);"
      ].map do |pattern|
        CodeSubstitution.new(pattern, "").tap { |subst|
          subst.on_substitution += lambda { |location, matched|
            source.on_inline_assembly.invoke(location, matched)
          }
        }
      end
    end
  end

end
end

==> adlint_1.10.0.orig.tar.gz: adlint-1.10.0/lib/adlint/cpp/asm.rb <==
# Inline assembly notations.
#
# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
# Copyright:: Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
# License::   GPLv3+: GNU General Public License version 3 or later
#
# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>

#--
#     ___    ____  __    ___   _________
#    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
#   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
#  / __  |/ /_/ / /___/ / /|  /  / /
# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
#
# This file is part of AdLint.
#
# AdLint is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# AdLint is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# AdLint.  If not, see <http://www.gnu.org/licenses/>.
#
#++

require "adlint/cpp/subst"

module AdLint #:nodoc:
module Cpp #:nodoc:

  module InlineAssemblyDefinition
    def create_inline_assembly_substitutions(source)
      [create_cxx_asm_definition(source)] +
        create_extended_asm_definitions(source)
    end

    def create_cxx_asm_definition(source)
      CodeSubstitution.new("asm(__adlint__any);", "").tap do |subst|
        subst.on_substitution += lambda { |matched_tokens|
          source.on_inline_assembly.invoke(matched_tokens)
        }
      end
    end

    def create_extended_asm_definitions(source)
      [
        "__asm(__adlint__any);",
        "asm { __adlint__any }",
        "__asm { __adlint__any }",
        "__asm__(__adlint__any);",
        "__asm__ volatile (__adlint__any);",
        "__asm__ __volatile__ (__adlint__any);",
        "asm(__adlint__any);",
        "asm volatile (__adlint__any);",
        "asm __volatile__ (__adlint__any);"
      ].map do |pattern|
        CodeSubstitution.new(pattern, "").tap { |subst|
          subst.on_substitution += lambda { |matched_tokens|
            source.on_inline_assembly.invoke(matched_tokens)
          }
        }
      end
    end
  end

end
end
